Translate Toolkit 1.13.0-rc1 — Translate Toolkit 2.0.0rc1 documentation

# Translate Toolkit 1.13.0-rc1

Released on 12 November 2014

This release contains many improvements and bug fixes. While it contains many general improvements, it also specifically contains needed changes for the upcoming Pootle 2.6.0 and Virtaal releases.

It is just over 3 months since the last release and there are many improvements across the board. A number of people contributed to this release and we’ve tried to credit them wherever possible (sorry if somehow we missed you).

## Highlighted improvements

### Major changes

- New converters for IDML format
- Extensive cleanup on ODF converters
- Some bugfixes and improvements

### Formats and Converters

- IDML
  - Added the `idml2po` and `po2idml` converters.
- ODF
  - Removed the `--engine` option in `odf2xliff` because the `itools` third party library is no longer used.
- TS
  - Pretty print output the same as Qt Linguist (issue 1420)

### Quality Checks

- Added the ability to skip some quality checks for the he, ug, zh_CN, zh_HK and zh_TW languages.

### Tools

- Removed the unnecessary dependency on `lxml` in `pretranslate` (issue 1909)

### General

- Fixed bug in file discovery that prevented Pootle Pootle’s terminology feature from working properly in some scenarios.
- Minor docs cleanups
- ODF code extensive cleanups:
  - Applied tons of PEP8 and style guide cleanups
  - Removed unused code
  - Removed unused test ODT file
  - Added lots of docstrings
  - Simplified code to ease maintainability and improve readability

...and loads of general code cleanups and of course many many bugfixes.

### Contributors

This release was made possible by the following people:

Leandro Regueiro, Yaron Shahrabani, Julen Ruiz Aizpuru, Jerome Leclanche.

And to all our bug finders and testers, a Very BIG Thank You.